@@ -2,17 +2,17 @@ import os
 
 import pandas as pd
 import yaml
-from termcolor2 import colored
-import logging
-
-from dwhutils.db_connection import connect_to_db
+from dotenv import load_dotenv
 from dwhutils.db_loader import LoadtoDB
+from termcolor2 import colored
 
 
 class DataVaultLoader:
 
-    def __init__(self, data: pd.DataFrame, db_con, entity_name: str,load_domain:str, t_name: str, date: str = None, schema: str = None,
+    def __init__(self, data: pd.DataFrame, db_con, entity_name: str, load_domain: str, t_name: str, date: str = None,
+                 schema: str = None,
                  commit_size: int = 10000, useSingeFetch: bool = False):
+        load_dotenv()
         self.data = data
         self.db_con = db_con
         self.entity_name = entity_name
@@ -23,18 +23,16 @@ class DataVaultLoader:
         self.commit_size = commit_size
         self.target_table = None
         self.useSingeFetch = useSingeFetch
-        if os.path.isfile(r'/Configs/ENB/' + self.entity_name + '.yaml'):
-            conf = r'/Configs/ENB/' + self.entity_name + '.yaml'
-        else:
-            conf = r'../Configs/ENB/' + self.entity_name + '.yaml'
+        conf = os.getenv('ENTITY_CONFIGS')
+        p_conf = os.path.join(conf, entity_name + '.yaml')
 
-        with open(conf) as file:
+        with open(p_conf) as file:
             self.documents = yaml.full_load(file)
         self.table_type = self.documents[entity_name]['tables'][self.t_name]['table_type']
         print("Build Loader")
         self.Loader = LoadtoDB(data=self.data, db_con=self.db_con, t_name=self.t_name, date=self.date,
                                schema=self.schema, commit_size=self.commit_size, entityName=self.entity_name,
-                               useSingeFetch=True,load_domain=self.load_domain)
+                               useSingeFetch=True, load_domain=self.load_domain)
 
     @property
     def load(self):
