@@ -10,7 +10,8 @@ from dwhutils.TableReader import read_raw_sql_sat
 from dwhutils.TechFields import add_technical_col
 from dwhutils.db_connection import connect_to_db
 from dwhutils.MongoLoader import MongoLoader
-
+import os
+from dotenv import load_dotenv
 
 
 class ILoader:
@@ -19,6 +20,10 @@ class ILoader:
                  loading_entity: str = None,
                  loading_sat: str = None, schema: str = None, report_name: str = None, bi_departement=None,
                  build_hash_key: bool = False):
+        load_dotenv()
+        self.config_file = os.getenv('DB_CONFIG')
+        self.kp_path = os.getenv('KEYPASS')
+        self.conf_r = os.getenv('ENTITY_CONFIGS')
         self.loader_type = loader_type
         self.target_connection = target_connection
         self.loading_sat = loading_sat
@@ -29,15 +34,12 @@ class ILoader:
         self.report_name = report_name
         self.bi_departement = bi_departement
         self.build_hash_key = build_hash_key
-        if os.path.isdir(r'/Configs/ENB/'):
-            self.conf_r = r'/Configs/ENB/'
-        else:
-            self.conf_r = r'../Configs/ENB/'
+        #self.conf_r = config_file
+
 
     def load(self, data: pd.DataFrame):
         print(colored('Load {0}'.format(self.loading_entity),'red'))
         if self.loader_type.upper() == 'DATAVAULT':
-            print("DataVault")
             self._datavault(data=data)
         elif self.loader_type.upper() == 'MONGO':
             self._mongo(data=data)
@@ -61,7 +63,7 @@ class ILoader:
         sat_data = add_technical_col(data=data, t_name=self.loading_sat, date=self.date,
                                      entity_name=self.loading_entity, buildHashKey=self.build_hash_key)
         sat_data.drop_duplicates(inplace=True)
-        with open(self.conf_r + self.loading_entity + '.yaml') as file:
+        with open(os.path.join(self.conf_r , self.loading_entity + '.yaml')) as file:
             documents = yaml.full_load(file)
         tables = documents[self.loading_entity]['tables']
         for i in tables:
